Changelog for yaml2rst
=========================

0.3 (2019-04-03)
----------------

* Add options ``--strip-regex`` and ``--yaml-strip-regex`` for
  filtering out Fold markers. See docs/fold-markers.rst for details.
* Add an example for formatting as definition lists.
* Make examples' HTML-build deterministic by removing the version
  number.
* Add support for Python 3.
* Convert the module into a package.
* Enhance the test-suite.
* Move the project to the `debops` group for shared development.
* Enable CI-tests (at Travis-CI).


..
 Local Variables:
 mode: rst
 ispell-local-dictionary: "american"
 End:
